- Sigma_u
remainder error variance-covariance matrix,
- Sigma_mu
individual error variance-covariance matrix,
- Sigma_nu
time error variance-covariance matrix,
- varnames
a vector whose elements are the names of the variables considered in the system equations, taking into account only the first appearance of those affected by restrictions on the coefficients,
- Estimate
vector of the coefficient estimates of the system equations, taking into account only the first appearance of those affected by restrictions,
- std_error
vector of the standard errors of the coefficient estimates, taking into account only the first appearance of those affected by restrictions,
- tstat
vector of the t-statistics associated to the coefficient estimates, taking into account only the first appearance of those affected by restrictions,
- pvalue
vector of the p-values associated to the t-statistics,
- infoSample
information on the considered dataset obtained trougth the pdim command of the plm package,
- neq
number of the system equations,
- Rsquared
list of R-squared obtained for each equation of the estimated system,
- method
method choosen for the system estimation.