Learn R Programming

panelSUR (version 0.1.0)

obtainSigmas: Compute errors' variance-covariance matrices

Description

This function aims to obtain the errors' variance-covariance matrices.

Usage

obtainSigmas(modelFrame=modelFrame,
             firstEstimate=firstEstimate,
             method=method)

Value

An object of class obtainSigmas, which is a list of the following elements:

Sigma_u

remainder error variance-covariance matrix,

Sigma_mu

individual error variance-covariance matrix,

Sigma_nu

time error variance-covariance matrix.

Arguments

modelFrame

an object of the class prepareData,

firstEstimate

an object of the class preliminaryEstimate,

method

the estimation method to be used, one of "1wayWB", "2wayWB", or "2wayQUE".