This function aims to obtain the preliminary (single within one or two way) estimate of the system equations.
preliminaryEstimate(modelFrame=modelFrame,
method=method)An object of class preliminaryEstimate, which is a list of the following elements:
centered residuals of the oneway within estimation obtained for each single equation of the system,
centered residuals of the twoways within estimation obtained for each single equation of the system,
individual means of the centered oneway within residuals,
individual means of the centered twoways within residuals,
time means of the centered twoways within residuals,
mean of the centered oneway within residuals,
list of the regressor matrix of each equation,
list of the regressors data frame of each equation,
a vector whose elements are the names of all the variables included in each equation of the system,
a vector whose elements are the names of the variables considered in the system equations, taking into account only the first appearance of those affected by restrictions on the coefficients.
an object of the class prepareData,
the estimation method to be used, one of "1wayWB", "2wayWB", or "2wayQUE".