This function aims to obtain the errors' variance-covariance matrices.
obtainSigmas(modelFrame=modelFrame,
firstEstimate=firstEstimate,
method=method)An object of class obtainSigmas, which is a list of the following elements:
remainder error variance-covariance matrix,
individual error variance-covariance matrix,
time error variance-covariance matrix.
an object of the class prepareData,
an object of the class preliminaryEstimate,
the estimation method to be used, one of "1wayWB", "2wayWB", or "2wayQUE".